@@ -1,8 +1,9 @@
 //! A vector-like array.
 
 use crate::{
-    defs::{LengthType, SpareMemoryPolicy},
     errors::{CapacityError, CapacityErrorVal, InsertError, InsertErrorVal},
+    len::LengthType,
+    mem::SpareMemoryPolicy,
 };
 use core::{
     marker::PhantomData,
@@ -44,7 +45,7 @@ use retain::*;
 /// # Examples
 ///
 /// ```rust
-/// # use cds::{arrayvec::ArrayVec, array_vec, defs::{Uninitialized, U8}};
+/// # use cds::{arrayvec::ArrayVec, array_vec, len::U8, mem::Uninitialized};
 /// let mut v = ArrayVec::<u64, U8, Uninitialized, 12>::new();
 /// assert_eq!(v.len(), 0);
 /// assert_eq!(v.capacity(), 12);
@@ -94,7 +95,7 @@ use retain::*;
 /// An `ArrayVec` can be created from an iterator:
 ///
 /// ```rust
-/// # use cds::{arrayvec::ArrayVec, defs::{Uninitialized, U8}};
+/// # use cds::{arrayvec::ArrayVec, len::U8, mem::Uninitialized};
 /// type A = ArrayVec<u64, U8, Uninitialized, 5>;
 /// let vec = vec![1, 2, 3, 4, 5];
 /// let a = vec.iter()
@@ -107,7 +108,7 @@ use retain::*;
 /// If the iterator yields more than [`CAPACITY`] elements, the method panics:
 ///
 /// ```should_panic
-/// # use cds::{arrayvec::ArrayVec, defs::{Uninitialized, U64}};
+/// # use cds::{arrayvec::ArrayVec, len::U64, mem::Uninitialized};
 /// type A = ArrayVec<u64, U64, Uninitialized, 3>; // <-- the capacity is 3
 /// let vec = vec![1, 2, 3, 4, 5];
 /// let a = vec.iter()                             // <-- but the iterator yields 5 elements
@@ -118,7 +119,7 @@ use retain::*;
 /// Avoid a panic with [`try_from_iter`] method, which returns [`CapacityError`] instead:
 ///
 /// ```rust
-/// # use cds::{arrayvec::ArrayVec, errors::CapacityError, defs::{Uninitialized, U64}};
+/// # use cds::{arrayvec::ArrayVec, errors::CapacityError, len::U64, mem::Uninitialized};
 /// type A = ArrayVec<u64, U64, Uninitialized, 3>;
 /// let vec = vec![1, 2, 3, 4, 5];
 /// let iter = vec.iter().map(|x| x * x);
@@ -151,7 +152,7 @@ where
     ///
     /// # Examples
     /// ```rust
-    /// # use cds::{arrayvec::ArrayVec, defs::{Uninitialized, U8}};
+    /// # use cds::{arrayvec::ArrayVec, len::U8, mem::Uninitialized};
     /// type A = ArrayVec<u64, U8, Uninitialized, 8>;
     /// let v = A::new();
     /// assert_eq!(A::CAPACITY, 8);
@@ -171,7 +172,7 @@ where
     /// # Examples
     ///
     /// ```rust
-    /// # use cds::{arrayvec::ArrayVec, defs::{Zeroed, U8}};
+    /// # use cds::{arrayvec::ArrayVec, len::U8, mem::Zeroed};
     /// let a = ArrayVec::<u64, U8, Zeroed, 8>::new();
     /// assert_eq!(a.capacity(), 8);
     /// assert_eq!(a.len(), 0);
@@ -634,7 +635,7 @@ where
     /// # Examples
     ///
     /// ```rust
-    /// # use cds::{arrayvec::ArrayVec, errors::CapacityError, defs::{Uninitialized, U8}};
+    /// # use cds::{arrayvec::ArrayVec, errors::CapacityError, len::U8, mem::Uninitialized};
     /// # use std::error::Error;
     /// # fn example() -> Result<(), CapacityError> {
     /// type A = ArrayVec<usize, U8, Uninitialized, 3>;
@@ -733,11 +734,11 @@ where
     /// ```rust
     /// # use cds::{array_vec, errors::InsertError};
     /// let mut v = array_vec![3; u64; 1, 2];
-    /// assert!(matches!(v.try_insert(3, 3), Err(InsertError::IndexOutOfBounds)));
+    /// assert!(matches!(v.try_insert(3, 3), Err(InsertError::InvalidIndex)));
     ///
     /// assert!(v.try_insert(0, 0).is_ok());
     /// assert_eq!(v, [0, 1, 2]);
-    /// assert!(matches!(v.try_insert(1, 3), Err(InsertError::CapacityError)));
+    /// assert!(matches!(v.try_insert(1, 3), Err(InsertError::InsufficientCapacity)));
     /// ```
     ///
     /// [`try_push`]: ArrayVec::try_push
@@ -747,10 +748,10 @@ where
     pub fn try_insert(&mut self, index: usize, value: T) -> Result<(), InsertError> {
         let len = self.len();
         if index > len {
-            return Err(InsertError::IndexOutOfBounds);
+            return Err(InsertError::InvalidIndex);
         }
         if len >= Self::CAPACITY {
-            return Err(InsertError::CapacityError);
+            return Err(InsertError::InsufficientCapacity);
         }
         unsafe {
             self.insert_unchecked(index, value);
@@ -780,7 +781,7 @@ where
     /// let mut v = array_vec![3; u64; 1, 2];
     /// assert!(matches!(
     ///     v.try_insert_val(5, 3),
-    ///     Err(InsertErrorVal::IndexOutOfBounds(v)) if v == 3
+    ///     Err(InsertErrorVal::InvalidIndex(v)) if v == 3
     /// ));
     /// assert_eq!(v, [1, 2]);
     ///
@@ -789,7 +790,7 @@ where
     ///
     /// assert!(matches!(
     ///     v.try_insert_val(1, 5),
-    ///     Err(InsertErrorVal::CapacityError(v)) if v == 5
+    ///     Err(InsertErrorVal::InsufficientCapacity(v)) if v == 5
     /// ));
     /// assert_eq!(v, [0, 1, 2]);
     /// ```
@@ -801,10 +802,10 @@ where
     #[inline]
     pub fn try_insert_val(&mut self, index: usize, value: T) -> Result<(), InsertErrorVal<T>> {
         if index > self.len.as_usize() {
-            return Err(InsertErrorVal::IndexOutOfBounds(value));
+            return Err(InsertErrorVal::InvalidIndex(value));
         }
         if self.len >= Self::CAPACITY {
-            return Err(InsertErrorVal::CapacityError(value));
+            return Err(InsertErrorVal::InsufficientCapacity(value));
         }
         unsafe {
             self.insert_unchecked(index, value);
