@@ -64,17 +64,17 @@
 #[macro_export]
 macro_rules! array_vec {
     ($c:expr; $t:ty) => {{
-        cds::arrayvec::ArrayVec::<$t, cds::defs::Usize, cds::defs::Uninitialized, $c>::new()
+        cds::arrayvec::ArrayVec::<$t, cds::len::Usize, cds::mem::Uninitialized, $c>::new()
     }};
     ($c:expr; $t:ty; $($e:expr),+ $(,)?) => {{
-        cds::arrayvec::ArrayVec::<$t, cds::defs::Usize, cds::defs::Uninitialized, $c>::try_from([$($e),*])
+        cds::arrayvec::ArrayVec::<$t, cds::len::Usize, cds::mem::Uninitialized, $c>::try_from([$($e),*])
             .expect("insufficient capacity")
     }};
     ($c:expr;) => {{
-        cds::arrayvec::ArrayVec::<_, cds::defs::Usize, cds::defs::Uninitialized, $c>::new()
+        cds::arrayvec::ArrayVec::<_, cds::len::Usize, cds::mem::Uninitialized, $c>::new()
     }};
     ($c:expr; $($e:expr),+ $(,)?) => {{
-        cds::arrayvec::ArrayVec::<_, cds::defs::Usize, cds::defs::Uninitialized, $c>::try_from([$($e),*])
+        cds::arrayvec::ArrayVec::<_, cds::len::Usize, cds::mem::Uninitialized, $c>::try_from([$($e),*])
             .expect("insufficient capacity")
     }};
 }
